import { toURLSearchParams } from '@wix/sdk-runtime/rest-modules';
import { transformSDKTimestampToRESTTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformRESTTimestampToSDKTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformSDKFieldMaskToRESTFieldMask } from '@wix/sdk-runtime/transformations/field-mask';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
import { resolveUrl } from '@wix/sdk-runtime/rest-modules';
function resolveWixHeadlessV1OAuthAppServiceUrl(opts) {
    const domainToMappings = {
        'manage._base_domain_': [
            {
                srcPath: '/oauth-app-service',
                destPath: '',
            },
            {
                srcPath: '/oauth-app',
                destPath: '',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/oauth-app',
                destPath: '',
            },
        ],
        'api._api_base_domain_': [
            {
                srcPath: '/oauth-app-service',
                destPath: '',
            },
        ],
    };
    return resolveUrl(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_auth-management_o-auth-apps';
/**
 * Creates a new OAuth app for a Wix Headless client.
 *
 * Use this API to enable headless functionality for a Wix site. An OAuth app allows external sites or apps to securely access your site's data and services using Wix APIs.
 */
export function createOAuthApp(payload) {
    function __createOAuthApp({ host }) {
        const serializedData = transformPaths(payload, [
            {
                transformFn: transformSDKTimestampToRESTTimestamp,
                paths: [{ path: 'oAuthApp.createdDate' }],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.headless.v1.o_auth_app',
            method: 'POST',
            methodFqn: 'wix.headless.v1.OAuthAppService.CreateOAuthApp',
            packageName: PACKAGE_NAME,
            url: resolveWixHeadlessV1OAuthAppServiceUrl({
                protoPath: '/v1/oauth-apps',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [{ path: 'oAuthApp.createdDate' }],
                },
            ]),
        };
        return metadata;
    }
    return __createOAuthApp;
}
/** Retrieves an OAuth app by ID. */
export function getOAuthApp(payload) {
    function __getOAuthApp({ host }) {
        const metadata = {
            entityFqdn: 'wix.headless.v1.o_auth_app',
            method: 'GET',
            methodFqn: 'wix.headless.v1.OAuthAppService.GetOAuthApp',
            packageName: PACKAGE_NAME,
            url: resolveWixHeadlessV1OAuthAppServiceUrl({
                protoPath: '/v1/oauth-apps/{oAuthAppId}',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [{ path: 'oAuthApp.createdDate' }],
                },
            ]),
        };
        return metadata;
    }
    return __getOAuthApp;
}
/**
 * Updates an OAuth app.
 *
 *
 * Only fields provided in `mask.paths` are updated.
 *
 * You can update the following fields:
 * + `name`
 * + `description`
 * + `allowedDomain`
 * + `loginUrl`
 * + `logoutUrl`
 * + `technology`
 */
export function updateOAuthApp(payload) {
    function __updateOAuthApp({ host }) {
        const serializedData = transformPaths(payload, [
            {
                transformFn: transformSDKFieldMaskToRESTFieldMask,
                paths: [{ path: 'mask' }],
            },
            {
                transformFn: transformSDKTimestampToRESTTimestamp,
                paths: [{ path: 'oAuthApp.createdDate' }],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.headless.v1.o_auth_app',
            method: 'PATCH',
            methodFqn: 'wix.headless.v1.OAuthAppService.UpdateOAuthApp',
            packageName: PACKAGE_NAME,
            url: resolveWixHeadlessV1OAuthAppServiceUrl({
                protoPath: '/v1/oauth-apps/{oAuthApp.id}',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [{ path: 'oAuthApp.createdDate' }],
                },
            ]),
        };
        return metadata;
    }
    return __updateOAuthApp;
}
/**
 * Deletes an OAuth app by ID.
 *
 *
 * > **Note:** After you delete an OAuth app, an external client can no longer make API calls by authenticating with its client ID.
 */
export function deleteOAuthApp(payload) {
    function __deleteOAuthApp({ host }) {
        const metadata = {
            entityFqdn: 'wix.headless.v1.o_auth_app',
            method: 'DELETE',
            methodFqn: 'wix.headless.v1.OAuthAppService.DeleteOAuthApp',
            packageName: PACKAGE_NAME,
            url: resolveWixHeadlessV1OAuthAppServiceUrl({
                protoPath: '/v1/oauth-apps/{oAuthAppId}',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
        };
        return metadata;
    }
    return __deleteOAuthApp;
}
/**
 * Retrieves a list of OAuth apps, given the provided paging, filtering, and sorting.
 *
 *
 * Query OAuth Apps runs with these defaults, which you can override:
 * + Results are sorted by `id` in descending order.
 * + `paging.offset` is `0`.
 */
export function queryOAuthApps(payload) {
    function __queryOAuthApps({ host }) {
        const metadata = {
            entityFqdn: 'wix.headless.v1.o_auth_app',
            method: 'POST',
            methodFqn: 'wix.headless.v1.OAuthAppService.QueryOAuthApps',
            packageName: PACKAGE_NAME,
            url: resolveWixHeadlessV1OAuthAppServiceUrl({
                protoPath: '/v1/oauth-apps/query',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [{ path: 'oAuthApps.createdDate' }],
                },
            ]),
        };
        return metadata;
    }
    return __queryOAuthApps;
}
/**
 * Generates a secret for an existing OAuth app.
 *
 *
 * > **Note:** You can only generate a secret once for each OAuth app, and the secret can't be retrieved later. Store the secret securely.
 */
export function generateOAuthAppSecret(payload) {
    function __generateOAuthAppSecret({ host }) {
        const metadata = {
            entityFqdn: 'wix.headless.v1.o_auth_app',
            method: 'POST',
            methodFqn: 'wix.headless.v1.OAuthAppService.GenerateOAuthAppSecret',
            packageName: PACKAGE_NAME,
            url: resolveWixHeadlessV1OAuthAppServiceUrl({
                protoPath: '/v1/oauth-apps/{oAuthAppId}/generate-secret',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __generateOAuthAppSecret;
}
//# sourceMappingURL=headless-v1-o-auth-app-o-auth-apps.http.js.map